@@ -20,10 +20,10 @@ catminat_download_to_local_directory<-function(directory){
     temp_dest<-tempfile(fileext=".xlsx")
     download.file(url,temp_dest,mode="wb")
 
-    catminat_df<-read_excel(temp_dest,sheet=1,col_names=T,col_types=rep("text",63))
+    catminat_df<-read_excel(temp_dest,sheet=1,col_names=T,col_types="text")
     
-    catminat_df<-catminat_df[grep("[0-9]+",catminat_df$rang_taxinomique,invert=T),]
-
+    ## catminat_df<-catminat_df[grep("[0-9]+",catminat_df$rang_taxinomique,invert=T),]
+    catminat_df <- as.data.frame(catminat_df)
 
     ##### TODO correggere nomi delle specie\
 
@@ -35,27 +35,30 @@ catminat_download_to_local_directory<-function(directory){
     ## avoid possible conflicts with non-
     ## ascii
     ## french chars
-    recode_catminat_values<-c("Lumi.{1}re"="ell_L_fr",
-                              "Temp.{1}rature"="elle_T_fr",
-                              "Continentalit.{1}"="ell_C_fr",
-                              "Humidit.{1}_.{1}daphique"="ell_U_fr",
-                              "R.{1}action_du_sol_.pH."="ell_R_fr",
-                              "Niveau_trophique"="ell_N_fr",
-                              "Salinit.*"="ell_S_fr",
-                              "Texture"="Soil_texture_fr",
-                              "Mati.*re_organique"="organic_matter_fr",
-                              "Humidit.*_atmosph.*rique"="ell_U_atm_fr",
-                              "pollinisation"="poll_vect_fr",
-                              "diss.*mination"="dissemination_fr",
-                              "couleur_fleur"="flower_colour_fr",
-                              "fruit"="fruit_type_fr",
-                              "sexualit.*"="sex_reprod_fr",
-                              "ordre_maturation"="order_of_maturation",
-                              "inflorescence"="inflorescence_fr",
-                              "Nom.Phytobase"="species_name",
-                              "TYPE_BIOLOGIQUE"="li_form_fr"
-                              )
-
+    recode_catminat_values<-c(
+        "N.*menclatural_BDNFF"="name_bdnff",
+        "NOM_SCIENTIFIQUE"="species_name",
+        "Lumi.{1}re"="ell_L_fr",
+        "Temp.{1}rature"="ell_T_fr",
+        "Continentalit.{1}"="ell_C_fr",
+        "Humidit.{1}_.{1}daphique"="ell_U_fr",
+        "R.{1}action_du_sol_.pH."="ell_R_fr",
+        "Niveau_trophique"="ell_N_fr",
+        "Salinit.*"="ell_S_fr",
+        "Texture"="Soil_texture_fr",
+        "Mati.*re_organique"="organic_matter_fr",
+        "Humidit.*_atmosph.*rique"="ell_U_atm_fr",
+        "pollinisation"="poll_vect_fr",
+        "diss.*mination"="dissemination_fr",
+        "couleur_fleur"="flower_colour_fr",
+        "fruit"="fruit_type_fr",
+        "sexualit.*"="sex_reprod_fr",
+        "ordre_maturation"="order_of_maturation",
+        "inflorescence"="inflorescence_fr",
+        "Nom.Phytobase"="species_name",
+        "TYPE_BIOLOGIQUE"="li_form_fr"
+    )
+    
     for(i in names(recode_catminat_values)){
         names(catminat_df)<-gsub(i,recode_catminat_values[i],names(catminat_df))
     }
@@ -63,8 +66,24 @@ catminat_download_to_local_directory<-function(directory){
     catminat_df$species_name<-as.character(catminat_df$species_name)
     catminat_df<-catminat_df[!is.na(catminat_df$species_name),]
 
+    ## Work on species names
 
+    namesH <- catminat_df$nomH
+    namesH <- gsub(" \\*$","",namesH)
+    namesH <- gsub(" H$","",namesH)
     
+    namesB <- catminat_df$nomB
+    namesB <- gsub(" \\*$","",namesB)
+    namesB <- gsub(" B$","",namesB)
+
+    namesA <- catminat_df$nomA
+    namesA <- gsub(" \\*$","",namesA)
+    namesA <- gsub(" A$","",namesA)
+
+    namesH[is.na(namesH)] <- namesB[is.na(namesH)]
+    namesH[is.na(namesH)] <- namesA[is.na(namesH)]
+    
+    catminat_df$species_name <- namesH
     catminat_df$species_name<-gsub("&amp","&",catminat_df$species_name,perl=TRUE)
     catminat_df$species_name<-gsub(";","",catminat_df$species_name,perl=TRUE)
     catminat_df$species_name<-gsub("\\s+\\*$","",catminat_df$species_name,perl=TRUE)
@@ -72,6 +91,7 @@ catminat_download_to_local_directory<-function(directory){
     catminat_df$species_name<-gsub("\\s+B$","",catminat_df$species_name,perl=TRUE)
 
 
+    catminat_df <- catminat_df[!is.na(catminat_df$species_name),]
     
 
     ## I split flowering dates into 2 columns,
@@ -82,9 +102,11 @@ catminat_download_to_local_directory<-function(directory){
     catminat_df<-data.frame(catminat_df,beg_flow_fr,end_flow_fr)
 
     
+    
     ## I choose only a subset of the available columns in baseflor dataset
     selected_columns_catminat<-c(
         "species_name",
+        "name_bdnff",
         "CHOROLOGIE",
         "inflorescence_fr",
         "sex_reprod_fr",
@@ -97,7 +119,7 @@ catminat_download_to_local_directory<-function(directory){
         "type_ligneux",
         "li_form_fr",
         "ell_L_fr",
-        "elle_T_fr",
+        "ell_T_fr",
         "ell_C_fr",
         "ell_U_atm_fr",
         "ell_U_fr",
@@ -108,12 +130,11 @@ catminat_download_to_local_directory<-function(directory){
         "organic_matter_fr",
         "beg_flow_fr",
         "end_flow_fr",
-        "PhytobaseID"
+        "numSpH"
         )
 
     catminat_df<-catminat_df[,selected_columns_catminat]
 
-
     ## recode inflorescenses types
     inflorescences<-c(
         "capitule de capitules$"="Compound capitulum",
@@ -177,42 +198,53 @@ catminat_download_to_local_directory<-function(directory){
     catminat_df$fruit_type_fr<-catminat_replace(catminat_df$fruit_type_fr,fruit_types)
 
     ## recode flower colours
-    flower_colours<-c("blanc$"="white",
-                      "jaune$"="yellow",
-                      "vert$"="green",
-                      "marron$"="brown",
-                      "bleu$"="blue",
-                      "jaune$"="yellow",
-                      "jauna$"="yellow",
-                      "noir$"="black"
+    ## flower_colours<-c("blanc$"="white",
+    ##                   "jaune$"="yellow",
+    ##                   "vert$"="green",
+    ##                   "marron$"="brown",
+    ##                   "bleu$"="blue",
+    ##                   "jaune$"="yellow",
+    ##                   "jauna$"="yellow",
+    ##                   "noir$"="black"
+    ##                   )
+
+    flower_colours<-c("blanc"="white",
+                      "jaune"="yellow",
+                      "vert"="green",
+                      "marron"="brown",
+                      "bleu"="blue",
+                      "jaune"="yellow",
+                      "jauna"="yellow",
+                      "noir"="black"
                       )
+
     catminat_df$flower_colour_fr<-catminat_replace(catminat_df$flower_colour_fr,flower_colours)
 
     ## recode dissemination types
     dissemination<-c(
-        "an.*mochore$"="anemochores",
-        "myrm.*cochore$"="myrmecochores",
-        "myrm.*cochore$"="myrmecochores",
-        "autochore$"="autochores",
-        "barochore$"="barochores",
-        "endozoochore$"="endozoochores",
-        "endozoochorie$"="endozoochores",
-        ".+pizoochore$"="epizoochores",              
-        "dyszoochore$"="dyszoochores", 
-        "hydrochore$"="hydrochores"                             
+        "an.*mochore"="anemochores",
+        "myrm.*cochore"="myrmecochores",
+        #"myrm.*cochore"="myrmecochores",
+        "autochore"="autochores",
+        "barochore"="barochores",
+        "endozoochore"="endozoochores",
+        "endozoochorie"="endozoochores",
+        ".+pizoochore"="epizoochores",              
+        "dyszoochore"="dyszoochores", 
+        "hydrochore"="hydrochores"                             
         )
     catminat_df$dissemination_fr<-catminat_replace(catminat_df$dissemination_fr,dissemination)
 
     ## recode sexual reproduction types
     sex_reprod<-c(
-        "androdio.{1}que$"="Androdioecy",
+        "androdio.{1}que"="Androdioecy",
         "gynomono.{1}que" ="Gynomonoecious",
-        "gynodio.{1}que$"="Gynodioecious",
-        "polygame$"="Polygamous",
-        "mono.{1}que$"="Monoecious",
-        "dio.{1}que$"="Dioecious",
-        "hermaphrodite$"="Hermaphroditic",
-        "polygame$"="Polygamous"
+        "gynodio.{1}que"="Gynodioecious",
+        "polygame"="Polygamous",
+        "mono.{1}que"="Monoecious",
+        "dio.{1}que"="Dioecious",
+        "hermaphrodite"="Hermaphroditic",
+        "polygame"="Polygamous"
         )
     catminat_df$sex_reprod_fr<-catminat_replace(catminat_df$sex_reprod_fr,sex_reprod)
 
@@ -243,42 +275,41 @@ catminat_download_to_local_directory<-function(directory){
 
     ## beware: catminat is now read with readxl package and empty cells are coded as <NA>. not as empty strings
     ##    catminat_df<-catminat_df[!(catminat_df$species_name=="Juncus articulatus" & catminat_df$sex_reprod_fr==""),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Juncus articulatus" & is.na(catminat_df$sex_reprod_fr)),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Capparis spinosa" & catminat_df$PhytobaseID=="13450"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Centaurium ery. erythraea" & catminat_df$PhytobaseID=="2361"),]
-##    catminat_df<-catminat_df[!(catminat_df$species_name=="Centaurium ery. erythraea" & catminat_df$PhytobaseID=="2361"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Chenopodium ambrosioides" & is.na(catminat_df$flower_colour_fr)),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Chenopodium opulifolium" & catminat_df$CHOROLOGIE=="cosmopolite"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Cornus sanguinea" & catminat_df$PhytobaseID=="2258"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Crataegus mon. monogyna" & catminat_df$PhytobaseID=="1657"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Daphne laureola" & catminat_df$PhytobaseID=="2084"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Eryngium bourgatii" & catminat_df$PhytobaseID=="11913"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Festuca ovi. ovina" & catminat_df$PhytobaseID=="352"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Gaudinia fragilis" & catminat_df$li_form_fr=="test(hbis)"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Genista salzmannii" & catminat_df$PhytobaseID=="12481"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Medicago turbinata" & catminat_df$PhytobaseID=="12456"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Ophrys bertolonii" & catminat_df$PhytobaseID=="725"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Populus nigra" & catminat_df$PhytobaseID=="7038"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Rhamnus saxatilis" & catminat_df$PhytobaseID=="16181"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Rosmarinus officinalis" & catminat_df$PhytobaseID=="16080"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Salix rosmarinifolia" & catminat_df$PhytobaseID=="795"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Salvia officinalis" & catminat_df$PhytobaseID=="14526"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Taraxacum sagittilobum" & catminat_df$PhytobaseID=="15326"),]
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Thlaspi rot. rotundifolium" & catminat_df$PhytobaseID=="1274"),]
-    
-    catminat_df<-catminat_df[!(catminat_df$species_name=="Linum bienne" & catminat_df$li_form_fr=="test(hbis)"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Juncus articulatus" & is.na(catminat_df$sex_reprod_fr)),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Capparis spinosa" & catminat_df$numSpH=="13450"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Centaurium ery. erythraea" & catminat_df$numSpH=="2361"),]
+##    catminat_df<-catminat_df[!(catminat_df$species_name=="Centaurium ery. erythraea" & catminat_df$numSpH=="2361"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Chenopodium ambrosioides" & is.na(catminat_df$flower_colour_fr)),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Chenopodium opulifolium" & catminat_df$CHOROLOGIE=="cosmopolite"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Cornus sanguinea" & catminat_df$numSpH=="2258"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Crataegus mon. monogyna" & catminat_df$numSpH=="1657"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Daphne laureola" & catminat_df$numSpH=="2084"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Eryngium bourgatii" & catminat_df$numSpH=="11913"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Festuca ovi. ovina" & catminat_df$numSpH=="352"),]
+    ## Gaudina has 2 different ecotypes... better to remove both to avoid misinterpretation
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Gaudinia fragilis"),]
+    ## catminat_df<-catminat_df[!(catminat_df$species_name=="Genista salzmannii" & catminat_df$numSpH=="12481"),]
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Medicago turbinata" & catminat_df$name_bdnff=="41226"),]
+    ## Remove Ophrys bertolonii subsp bertolonii
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Ophrys bertolonii" & catminat_df$name_bdnff=="81834"),]
+    ## Leave only Populus nigra removing subspecies
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Populus nigra" & catminat_df$name_bdnff=="52035"),]
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Populus nigra" & catminat_df$name_bdnff=="52031"),]
+
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Rhamnus saxatilis" & catminat_df$name_bdnff=="118976"),]
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Rosmarinus officinalis" & catminat_df$name_bdnff=="57822"),]
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Salvia officinalis" & catminat_df$name_bdnff=="60181"),]
+    catminat_df<-catminat_df[!(catminat_df$species_name=="Linum bienne"),]
 
     ## remove double entries
     catminat_df<-catminat_df[!(duplicated(catminat_df)),]
 
-    ## fix flowering dates for Medicago turbinata
-    catminat_df[catminat_df$PhytobaseID==12456,c("beg_flow_fr","end_flow_fr")]<-c(4,6)
     ## and remove double entry
-    catminat_df<-catminat_df[catminat_df$PhytobaseID!=11083,]
+    ##catminat_df<-catminat_df[catminat_df$numSpH!=11083,]
 
     ## fix CHOROLOGIE for Rubus cinerascens and  Rubus conspicuus and then remove double entries
-    catminat_df<-catminat_df[(1:nrow(catminat_df))!=which(catminat_df$species_name=="Rubus cinerascens")[1],]
-    catminat_df<-catminat_df[(1:nrow(catminat_df))!=which(catminat_df$species_name=="Rubus conspicuus")[1],]
+    ## catminat_df<-catminat_df[(1:nrow(catminat_df))!=which(catminat_df$species_name=="Rubus cinerascens")[1],]
+    ## catminat_df<-catminat_df[(1:nrow(catminat_df))!=which(catminat_df$species_name=="Rubus conspicuus")[1],]
 
     ##catminat_df<-catminat_df[row.names(catminat_df)!=(which(catminat_df$species_name=="Erodium glandulosum")[1]),]
     ##catminat_df<-catminat_df[row.names(catminat_df)!=(which(catminat_df$species_name=="Erodium rupicola")[1]),]
